@@ -1,4 +1,4 @@
-# $Id: Signals.pm 2357 2008-06-20 17:41:54Z rcaputo $
+# $Id: Signals.pm 2478 2009-03-01 18:55:04Z rcaputo $
 
 # The data necessary to manage signals, and the accessors to get at
 # that data in a sane fashion.
@@ -6,13 +6,15 @@
 package POE::Resource::Signals;
 
 use vars qw($VERSION);
-$VERSION = do {my($r)=(q$Revision: 2357 $=~/(\d+)/);sprintf"1.%04d",$r};
+$VERSION = do {my($r)=(q$Revision: 2478 $=~/(\d+)/);sprintf"1.%04d",$r};
 
 # These methods are folded into POE::Kernel;
 package POE::Kernel;
 
 use strict;
 
+use POSIX qw(:sys_wait_h);
+
 ### Map watched signal names to the sessions that are watching them
 ### and the events that must be delivered when they occur.
 
@@ -186,6 +188,7 @@ sub _data_sig_finalize {
 
   unless (RUNNING_IN_HELL) {
     local $!;
+    local $?;
     until ((my $pid = waitpid( -1, 0 )) == -1) {
       _warn( "!!! Child process PID:$pid reaped: $!\n" ) if $pid;
       $finalized_ok = 0;
@@ -611,16 +614,6 @@ sub _data_sig_child_procs {
   return $kr_child_procs;
 }
 
-# Reap child processes.  Discard their statuses.  Used to prevent
-# zombie processes when nobody else is watching for children.  See
-# POE::Loop::Event for its use.
-
-sub _data_sig_ignore_sigchld {
-  my $pid;
-  1 while $pid = waitpid(-1, WNOHANG);
-  $kr_child_procs = !$pid;
-}
-
 1;
 
 __END__
@@ -664,3 +657,4 @@ Please see L<POE> for more information about authors and contributors.
 =cut
 
 # rocco // vim: ts=2 sw=2 expandtab
+# TODO - Edit.
