@@ -1,9 +1,11 @@
+# $Id: Wheel.pm 2447 2009-02-17 05:04:43Z rcaputo $
+
 package POE::Wheel;
 
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '1.294_512'; # NOTE - Should be #.### (three decimal places)
+$VERSION = do {my($r)=(q$Revision: 2447 $=~/(\d+)/);sprintf"1.%04d",$r};
 
 use Carp qw(croak);
 
@@ -56,22 +58,13 @@ Object lifetime is very important for POE wheels.  At creation time,
 most wheels will add anonymous event handlers to the currently active
 session.  In other words, the session that created the wheel is
 modified to handle new events.  Event watchers may also be initialized
-as necessary to trigger the new handlers.  These event watchers are
-also owned by the session that created the wheel.
+as necessary to trigger the new handlers.
 
-Sessions must not expose their wheels to other sessions.  Doing so
-will likely cause problems because wheels are tightly integrated with
-the sessions that created them.  For example, calling put() on a
-POE::Wheel::ReadWrite instance may enable a write-okay watcher.  The
-handler for this watcher is already defined in the wheel's owner.
-Calling put() outside that session will enable the write-okay watcher
-in the wrong session, and the event will never be handled.
-
-Likewise, wheels must be destroyed from within their creator sessions.
-Otherwise breakage will occur when the wheels' DESTROY methods try to
-unregister event handlers and watchers from the wrong sessions.  To
-simplify things, it's recommended to store POE::Wheel instances in
-heaps of the sessions that created them.
+Destroying a wheel will unregister the encapsulated anonymous event
+handlers and stop any active event watchers associated with the
+wheel's task.  It's therefore imperative that the object be saved
+somewhere for as long as it's needed.  The heap of the session that
+created the wheel is a good place.
 
 For example, creating a POE::Wheel::FollowTail object will register an
 event handler that periodically polls a file for new information.  It
@@ -193,7 +186,7 @@ EVENT_TYPEs differ for each wheel and correspond to the constructor
 parameters that match /.*Event$/.  For example, POE::Wheel::ReadWrite
 may emit up to five different kinds of event: InputEvent, ErrorEvent,
 FlushedEvent, HighEvent, LowEvent.  The name of each emitted event may
-be changed at run time.
+be changed at runtime.
 
 This example changes the events to emit on new input and when output
 is flushed.  It stops the wheel from emitting events when errors
