@@ -1,13 +1,14 @@
+# $Id: ReadWrite.pm 2488 2009-03-02 20:17:53Z bingosnet $
+
 package POE::Wheel::ReadWrite;
 
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '1.294_512'; # NOTE - Should be #.### (three decimal places)
+$VERSION = do {my($r)=(q$Revision: 2488 $=~/(\d+)/);sprintf"1.%04d",$r};
 
 use Carp qw( croak carp );
 use POE qw(Wheel Driver::SysRW Filter::Line);
-use base qw(POE::Wheel);
 
 # Offsets into $self.
 sub HANDLE_INPUT               () {  0 }
@@ -99,8 +100,8 @@ sub new {
         $mark_errors++;
       }
     }
-    if (defined $params{HighEvent} and not defined $params{HighMark}) {
-      carp "HighEvent requires a corresponding HighMark";
+    if (defined($params{HighMark}) xor defined($params{HighEvent})) {
+      carp "HighMark and HighEvent parameters require each-other";
       $mark_errors++;
     }
     if (defined($params{LowMark}) xor defined($params{LowEvent})) {
@@ -229,7 +230,7 @@ sub _define_write_state {
         $$event_flushed && $k->call($me, $$event_flushed, $unique_id);
       }
     }
-  );
+ );
 
   $poe_kernel->select_write($self->[HANDLE_OUTPUT], $self->[STATE_WRITE]);
 
@@ -389,12 +390,12 @@ sub DESTROY {
   # Turn off the select.  This is a problem if a wheel is being
   # swapped, since it will turn off selects for the other wheel.
   if ($self->[HANDLE_INPUT]) {
-    $poe_kernel->select_read($self->[HANDLE_INPUT]);
+    $poe_kernel->select($self->[HANDLE_INPUT]);
     $self->[HANDLE_INPUT] = undef;
   }
 
   if ($self->[HANDLE_OUTPUT]) {
-    $poe_kernel->select_write($self->[HANDLE_OUTPUT]);
+    $poe_kernel->select($self->[HANDLE_OUTPUT]);
     $self->[HANDLE_OUTPUT] = undef;
   }
 
@@ -795,7 +796,7 @@ TODO - Example.
 =head4 OutputFilter
 
 InputFilter and OutputFilter may be used to specify different filters
-for input and output. Please see L</InputFilter> for more information
+for input and output.  Please see L</InputFilter> for more informatin
 and an example.
 
 =head4 InputEvent
@@ -875,20 +876,11 @@ error event is dispatched.
 C<ARG3> contains the wheel's unique ID.  The wheel's ID is used to
 differentiate between many wheels managed by a single session.
 
-ErrorEvent may also indicate EOF on a FileHandle by returning
-operation "read" error 0.  For sockets, this means the remote end has
-closed the connection.
-
 A sample ErrorEvent handler:
 
   sub error_state {
     my ($operation, $errnum, $errstr, $id) = @_[ARG0..ARG3];
-    if ($operation eq "read" and $errnum == 0) {
-      print "EOF from wheel $id\n";
-    }
-    else {
-      warn "Wheel $id encountered $operation error $errnum: $errstr\n";
-    }
+    warn "Wheel $id encountered $operation error $errnum: $errstr\n";
     delete $_[HEAP]{wheels}{$id}; # shut down that wheel
   }
 
@@ -950,7 +942,7 @@ put() accepts a list of RECORDS, which will be serialized by the
 wheel's Filter and buffered and written by its Driver.
 
 put() returns true if a HighMark has been set and the Driver's output
-buffer has reached or exceeded the limit.  False is returned if
+buffer has reached or exceded the limit.  False is returned if
 HighMark has not been set, or if the Driver's buffer is smaller than
 that limit.
 
@@ -963,7 +955,7 @@ syntax if HighMark isn't set: the application will fail spectacularly!
 
 event() allows an application to modify the events emitted by a
 POE::Wheel::ReadWrite object.  All constructor parameters ending in
-"Event" may be changed at run time: L</InputEvent>, L</FlushedEvent>,
+"Event" may be changed at runtime: L</InputEvent>, L</FlushedEvent>,
 L</ErrorEvent>, L</HighEvent>, and L</LowEvent>.
 
 Setting an event to undef will disable the code within the wheel that
@@ -1032,7 +1024,7 @@ TODO - Example.
 Sets the high water mark---the number of octets that designates a
 "full enough" output buffer.  A POE::Wheel::ReadWrite object will emit
 a HighEvent when its output buffer expands to reach this point.  All
-put() calls will return true when the output buffer is equal or
+put() calls will reutrn true when the output buffer is equal or
 greater than HIGH_MARK_OCTETS.
 
 Both HighEvent and put() indicate that it's unsafe to continue writing
@@ -1092,7 +1084,7 @@ TODO - Example.
 
 =head2 get_output_handle
 
-get_output_handle() returns the filehandle being watched for output.
+get_input_handle() returns the filehandle being watched for input.
 
 Manipulating filehandles that are managed by POE may cause nasty side
 effects, which may change from one POE release to the next.  Please
@@ -1106,7 +1098,7 @@ Call shutdown($fh,0) on a POE::Wheel::ReadWrite object's input
 filehandle.  This only works for sockets; nothing will happen for
 other types of filehandle.
 
-Occasionally, the POE::Wheel::ReadWrite object will stop monitoring
+tionally, the POE::Wheel::ReadWrite object will stop monitoring
 its input filehandle for new data.  This occurs regardless of the
 filehandle type.
 
@@ -1118,8 +1110,8 @@ Call shutdown($fh,1) on a POE::Wheel::ReadWrite object's output
 filehandle.  This only works for sockets; nothing will happen for
 other types of filehandle.
 
-Occasionally, the POE::Wheel::ReadWrite object will stop monitoring its
-output filehandle for new data. This occurs regardless of the
+tionally, the POE::Wheel::ReadWrite object will stop monitoring its
+output filehandle for new data.  This occurs regardless of the
 filehandle type.
 
 TODO - Example.
@@ -1135,7 +1127,7 @@ TODO - Example.
 =head2 get_driver_out_messages
 
 L<POE::Driver> objects' output buffers may be message based.  Every put()
-call may be buffered individually.  get_driver_out_messages() will
+call may be buffered individualy.  get_driver_out_messages() will
 return the number of pending put() messages that remain to be sent.
 
 Stream-based drivers will simply return 1 if any data remains to be
